import logging

try:
    import boto3

    # this gets logged 6 times
    boto3.set_stream_logger(name="botocore.credentials", level=logging.WARNING)
    # the 7th logging message of credentials came from aiobotocore
    boto3.set_stream_logger(name="aiobotocore.credentials", level=logging.WARNING)
    boto3.set_stream_logger(name="urllib3.connectionpool", level=logging.WARNING)
except ImportError:
    pass



import platform
import sys

from loguru import logger

if platform.system() == "Windows":
    format = "{level.name} {message}"
else:
    format = "{level.icon} {message}"

default_handler = dict(
    sink=sys.stdout,
    format=format,
    level="INFO",
)

logger.configure(handlers=[default_handler])
logger.level("SUCCESS", icon="✅")
logger.level("WARNING", icon="🔶")


# ANSI color code: https://gist.github.com/iansan5653/c4a0b9f5c30d74258c5f132084b78db9
ANSI_COLORS = dict(
    bold="\x1b[1m",
    black="\x1b[1;90m",
    red="\x1b[1;91m",
    green="\x1b[1;92m",
    yellow="\x1b[1;93m",
    blue="\x1b[1;94m",
    purple="\x1b[1;95m",
    cyan="\x1b[1;96m",
    white="\x1b[1;97m",
    reset="\x1b[0m",
)


class colors:
    """Coloring texts."""

    @staticmethod
    def bold(text):
        return f"{ANSI_COLORS['bold']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def black(text):
        return f"{ANSI_COLORS['black']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def red(text):
        return f"{ANSI_COLORS['red']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def green(text):
        return f"{ANSI_COLORS['green']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def yellow(text):
        return f"{ANSI_COLORS['yellow']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def blue(text):
        return f"{ANSI_COLORS['blue']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def purple(text):
        return f"{ANSI_COLORS['purple']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def cyan(text):
        return f"{ANSI_COLORS['cyan']}{text}{ANSI_COLORS['reset']}"

    @staticmethod
    def white(text):
        return f"{ANSI_COLORS['white']}{text}{ANSI_COLORS['reset']}"



# Raise warnings for python versions that are not tested
import platform

from packaging import version

from ._core import logger

py_version = version.parse(platform.python_version())


def py_version_warning(min_v: str, max_v: str):
    """Print warning for python versions that are not tested in CI."""
    max_v_plus_1 = (
        ".".join(max_v.split(".")[:-1]) + "." + str(int(max_v.split(".")[-1]) + 1)
    )

    if py_version >= version.parse(max_v_plus_1) or py_version < version.parse(min_v):
        logger.warning(
            f"You are running {py_version}\nOnly python versions {min_v}~"
            f"{max_v} are currently tested, use at your own risk."
        )
